Skip to contents

Inserts the markdown text for a coverage badge in the usethis block (between <!-- badges: start --> and <!-- badges: end -->). The src URL for the badge SVG points to a storage branch in the repo(covr2gh-storage). The link out points to the actions workflow page.

Usage

use_covr2gh_badge()

Examples

if (FALSE) { # \dontrun{
use_covr2gh_badge()
} # }